clear 
set more off
capture log close


*Change filepath to location 
cd [insert filepath]


log using create.log, replace

*21 August 2012
**********************************************************************************
*Purpose:																		 *
*The purpose of this do file is to create the datasets that are used in the 	 *
* econometric modelling of revenue (see Attachment H for discussion and results) *
**********************************************************************************


/* This do file creates the following datasets used in the "model.do" file:

(a) edb_revenue1 -- a panel dataset with line charge revenue by EDB based on information disclosure information and GDP estimates for the areas covered by supplier.  
    This data is used in the model.do file section (a)   

(b) 53zd_revenue_gdp -- a panel dataset with line charge revenue from industrial and commercial users from a s 53ZD information request and GDP estimates for the areas covered by supplier.
    This data is used in the model.do file section (b) 
*/


*******************
***start do file***
*******************

*******************************************************
*Importing additional data needed on revenue, cpi, gdp*
*******************************************************

**************************************************************************************************
***Importing GDP estimates for the areas covered by suppliers networks							 *	
* based on NZIER regional GDP, aportioned to suppliers using methodoogy desribed in Attachment H *
**************************************************************************************************

clear
insheet using "regionalGDP.csv", double clear
encode edb, gen(id)
drop edb
rename id edb

save regionalGDP, replace



**********************************************
***Importing CPI                             *  
*used to deflate revenue to 2011 real prices *
**********************************************

clear
insheet using "cpi.csv", double clear
save cpi,replace

***************************************************************
***Importing line charge revenue from  information disclosures*
***************************************************************

clear
insheet using "revenue1.csv", double clear
save revenue1, replace

*drop subregions
drop if edb == "Aurora Central"
drop if edb == "Aurora Dunedin" 
drop if edb == "Eastland Wairoa" 
drop if edb == "Eastland Gisborne" 
drop if edb == "Powerco - Western" 
drop if edb == "Powerco - Eastern" 
drop if edb == "Unison - Hawkes Bay"
drop if edb == "Unison - Central Region"
drop if edb == "Vector - Auckland" 
drop if edb == "Vector - Northern" 
 
list edb

encode edb, gen(id)
drop edb
rename id edb

save revenue1, replace


****************************************************************************
*(a) Create the dataset for the models based on information disclosure data*
****************************************************************************************

** edb_revenue1 -- a panel dataset with line charge revenue by EDB based on information disclosures("revenue1"), merged with supplier GDP estimates ("regionalgdp"). 
** This is used in the model.do file section (a)   

use revenue1
gen lnrev  = log( net_revenue_real)
joinby edb year using regionalgdp,unmatched(both)
gen lngdp1 = log(  g_realgdp_regional)
save edb_revenue1,replace 

************************************************************************
*(b) Creating a dataset for the EDB specific models based on 53ZD data *
************************************************************************

** 53zd_revenue_gdp -- a panel dataset with line charge revenue from industrial and commercial users from a s 53ZD information request("53zd_all.dta"), merged with GDP estimates ("regional gdp")for the areas covered by supplier.
** This data is used in the model.do file section (b)     

insheet using "53zdmodel.csv", double clear

encode edb, gen(id)
order id
drop edb
rename id edb

*************************************************************************************************************************
*generate new variables for line charge revenue from residential users, and revenue from industrial and commercial users*
*************************************************************************************************************************

* this revenue information is used for purposes of this analysis
* many EDBs only provided line charge revenue, and not also the breakdown into distribution and tranmission line charge revenue. Therefore just use line charge revenue was used for this analysis


*** line charge revenue for residential users
gen res_linechargerev_000   =   ///
	res_netlinechargerev_000 + s_netlinechargerev_000+small_25kva_netlinechargerev_000

*** line charge revenue for industial and commercial users
gen ic_linechargerev_000    =  ///
	c_netlinechargerev_000 + i_netlinechargerev_000 + large_netlinechargerev_000 + ///
	large_top5_netlinechargerev_000 +  over70kva_netlinechargerev_000 + largedirect_netlinechargerev_000 + ///
	m_netlinechargerev_000 + med_25_70_netlinechargerev_000 + other_netlinechargerev_000 + small_c_netlinechargerev_000 

*** total line charge revenue
gen total_linechargerev_000 = res_linechargerev_000 + ic_linechargerev_000

label variable res_linechargerev_000   "Line charge revenue from residential users"
label variable ic_linechargerev_000    "Line charge revenue from industrial & commercial users"
label variable total_linechargerev_000 "Line charge revenue"


**************************************************************************************************************************************
*generate new variables for distribution line charge revenue from residential users, and revenue from industrial and commercial users*
*************************************************************************************************************************************

*** distribution line charge revenue for residential users
gen res_dlinechargerev_000   =   ///
	res_distrev_000 + s_distrev_000 + small_25kva_distrev_000

*** distribution line charge revenue for industrial and commercial users
gen ic_dlinechargerev_000    =  ///
	c_distrev_000+ i_distrev_000 + large_distrev_000 + ///
	large_top5_distrev_000 + over70kva_distrev_000 + largedirect_distrev_000 + ///
	m_distrev_000 + med_25_70_distrev_000 + other_distrev_000 + small_c_distrev_000 

*** total distribution line charge revenue 
gen total_dlinechargerev_000 = res_dlinechargerev_000  + ic_dlinechargerev_000

label variable res_dlinechargerev_000   "Distribution line charge revenue from residential users"
label variable ic_dlinechargerev_000    "Distribution line charge revenue from industrial & commercial users"
label variable total_dlinechargerev_000 "Distribution line charge revenue"

**************************************************************************************************************************************
*generate new variables for transmission line charge revenue from residential users, and revenue from industrial and commercial users*
*************************************************************************************************************************************
*** Not all suppliers have tranmission line charge revenue data available


*** transmission line charge revenue for residential users
gen res_tlinechargerev_000   =   ///
	res_transrev_000 + s_transrev_000 + small_25kva_transrev_000

*** transmission line charge revenue for industrial and commercial users
gen ic_tlinechargerev_000    =  ///
	c_transrev_000+ i_transrev_000 + large_transrev_000 + ///
	large_top5_transrev_000 + over70kva_transrev_000 + largedirect_transrev_000 + ///
	m_transrev_000 + med_25_70_transrev_000 + other_transrev_000 + small_c_transrev_000 

gen total_tlinechargerev_000 = res_tlinechargerev_000 + ic_tlinechargerev_000

label variable res_tlinechargerev_000   "Transmission line charge revenue from residential users"
label variable ic_tlinechargerev_000    "Transmission line charge revenue from industrial & commercial users"
label variable total_tlinechargerev_000 "Transmission line charge revenue"


********************************************************************
*Creating a dataset with explanatory variable, ie regional real GDP *
********************************************************************

joinby edb year using regionalgdp,unmatched(both)
drop _merge

*Merge in cpi deflator

joinby year using cpi, unmatched(both)


* browse edb year res_q_supplied_mwh i_q_supplied_mwh _merge g_realgdp_regional index_gdp


**************************************************************
* dropping variables and year not required for this modelling*
**************************************************************
 
* 53zd data only starts in 2008 so drop years before that

keep if year > 2007

*Only keep revenue variables used in this analysis (ie line charge revenue for residential users and commerical and industrial users) and keep GDP and CPI

keep  edb year res_linechargerev_000 ic_linechargerev_000  total_linechargerev_000 g_realgdp_regional cpi

* convert all  variables to real 2011 values using CPI deflator (ie 2011=1)
* We used "replace" so that the modelling in model.do which uses these variable names continues to work without further changes

replace res_linechargerev_000   =  res_linechargerev_000 * cpi
replace ic_linechargerev_000    =  ic_linechargerev_000 * cpi
replace total_linechargerev_000 =  total_linechargerev_000 *cpi


*******************
* generate logs   *
*******************

gen lnrev_ic     = log(ic_linechargerev_000)
gen lnrev_res    = log(res_linechargerev_000)
gen lnrev_total  = log(total_linechargerev_000)
gen lngdp        = log(  g_realgdp_regional)


save 53zd_revenue_gdp, replace


log close 
clear

